pontil/types
Type definitions for pontil.
Types
Optional properties that can be sent with output annotation commands (notice,
error, and warning). See create a check run for more information about
annotations.
pub type AnnotationProperties {
Title(String)
File(String)
StartLine(Int)
EndLine(Int)
StartColumn(Int)
EndColumn(Int)
}
Constructors
-
Title(String)A title for the annotation.
-
File(String)The path of the file for which the annotation should be created.
-
StartLine(Int)The start line for the annotation.
-
EndLine(Int)The end line for the annotation. Defaults to
StartLinewhenStartLineis provided. -
StartColumn(Int)The start column for the annotation. Cannot be sent when
StartLineandEndLineare different values. -
EndColumn(Int)The end column for the annotation. Cannot be sent when
StartLineandEndLineare different values. Defaults toStartColumnwhenStartColumnis provided.
The exit code for an action.
pub type ExitCode {
Failure
Success
}
Constructors
-
FailureA code indicating that the action was a failure (1)
-
SuccessA code indicating that the action was successful (0)
Options for reading inputs values in an action.
pub type InputOptions {
InputOptions(required: Bool, trim_whitespace: Bool)
}
Constructors
-
InputOptions(required: Bool, trim_whitespace: Bool)Arguments
- required
-
Whether the input is required. If required and not present, will return an error. Defaults to false.
- trim_whitespace
-
Whether leading/trailing whitespace will be trimmed for the input. Defaults to true.
Platform Details
pub type OSInfo {
OSInfo(
name: String,
version: String,
platform: String,
arch: String,
os_type: OSType,
is_windows: Bool,
is_macos: Bool,
is_linux: Bool,
)
}
Constructors
-
OSInfo( name: String, version: String, platform: String, arch: String, os_type: OSType, is_windows: Bool, is_macos: Bool, is_linux: Bool, )Arguments
- name
-
The name of the Operating System release. This will be
""if the value cannot be determined. - version
-
The version of the Operating System release. This will be
""if the value cannot be determined. - platform
-
The platform the system is running on. This may be unknown.
- arch
-
The architecture the system is running on. This may be unknown.
- os_type
-
The type of the operating system.